==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/my_shoutbox.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="my_shoutbox.php" method="post" name="action">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="4" class="txt_title" align="right">
						<?php echo $lang['hdr_latest_shouts'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($shouts)) {
				foreach($shouts as $key => $i):
				?>
			    <tr valign="top">
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<?php echo $i['shoutbox_create_datetime'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['shoutbox_body'];?><br />
					</td>
					<td align="right" valign="top">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['profile_nic'];?></a><br />
					</td>
			    </tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="4">
						<?php echo $lang['err_no_shouts'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<?php
			if ($this->user_acs->checkPermission($resource_ids['shoutbox'], $privilege_ids['add_item'])) { //resourece_id, Priv_id
			?>
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_add_shout'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<?php echo $lang['txt_add_shout'];?><br />
					</td>
			    </tr>
			    <tr>
					<td colspan="2">
						<textarea name="data[shout_text]" class="formInput" onKeyPress="return updateCharsLeft(this, event, 200)" onBlur="truncatefield(this)" onChange="truncatefield(this)" onKeyUp="truncatefield(this)" cols="22" rows="10"></textarea><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" size="3" name="charsleft" value="200" disabled onFocus="this.form.sub.focus()" /><br />
					</td>
					<td align="right">
						<input type="submit" name="insert_shout" value="<?php echo $lang['sub_shout'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_shoutbox'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_what_is_shout'];?><br />
					</td>
				</tr>
			</table>
			<?php
			}
			?>
		</td>
	</tr>
</table>
</form>

<script language="javascript">
<!--

function messageLength( theForm ) {
	return theForm.data[shout_text].value.length
	}

function updateCharsLeft(obj, evt) {
	var stupidMac = false;

	if (navigator.appVersion.search("MSIE 4.5; Macintosh") > -1) {
		stupidMac = true;
	}

	var charsLeft = 200 - messageLength( obj.form )
	obj.form.charsleft.value = charsLeft;
	var allowKey = false;

	var keyCode = (navigator.appName == "Netscape") ? evt.which : evt.keyCode;
	if ((keyCode > 31 || keyCode == 10 || keyCode == 13) && obj.value.length < 200) {
		allowKey = true;
	}

	if (keyCode == 8) {
		allowKey = true;
	}

	if (allowKey == true) {
		return stupidMac == true ? keyCode : true;
	} else {
		return stupidMac == true ? 0 : false;
	}
}

function truncatefield(obj) {
	var charsLeft = 200 - messageLength( obj.form )
	if (charsLeft < 0) {
		obj.value = obj.value.substring(0, obj.value.length + charsLeft)
		charsLeft = 0
	}
	obj.form.charsleft.value = charsLeft;
}

//-->
</script>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/my_shoutbox.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="my_shoutbox.php" method="post" name="action">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="4" class="txt_title" align="right">
						<?php echo $lang['hdr_latest_shouts'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($shouts)) {
				foreach($shouts as $key => $i):
				?>
			    <tr valign="top">
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<?php echo $i['shoutbox_create_datetime'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['shoutbox_body'];?><br />
					</td>
					<td align="right" valign="top">
						<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['profile_nic'];?></a><br />
					</td>
			    </tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="4">
						<?php echo $lang['err_no_shouts'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="180" valign="top">
			<?php
			if ($this->user_acs->checkPermission($resource_ids['shoutbox'], $privilege_ids['add_item'])) { //resourece_id, Priv_id
			?>
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_add_shout'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<?php echo $lang['txt_add_shout'];?><br />
					</td>
			    </tr>
			    <tr>
					<td colspan="2">
						<textarea name="data[shout_text]" class="formInput" onKeyPress="return updateCharsLeft(this, event, 200)" onBlur="truncatefield(this)" onChange="truncatefield(this)" onKeyUp="truncatefield(this)" cols="22" rows="10"></textarea><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" size="3" name="charsleft" value="200" disabled onFocus="this.form.sub.focus()" /><br />
					</td>
					<td align="right">
						<input type="submit" name="insert_shout" value="<?php echo $lang['sub_shout'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_shoutbox'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_what_is_shout'];?><br />
					</td>
				</tr>
			</table>
			<?php
			}
			?>
		</td>
	</tr>
</table>
</form>

<script language="javascript">
<!--

function messageLength( theForm ) {
	return theForm.elements[0].value.length
	}

function updateCharsLeft(obj, evt) {
	var stupidMac = false;

	if (navigator.appVersion.search("MSIE 4.5; Macintosh") > -1) {
		stupidMac = true;
	}

	var charsLeft = 200 - messageLength( obj.form )
	obj.form.charsleft.value = charsLeft;
	var allowKey = false;

	var keyCode = (navigator.appName == "Netscape") ? evt.which : evt.keyCode;
	if ((keyCode > 31 || keyCode == 10 || keyCode == 13) && obj.value.length < 200) {
		allowKey = true;
	}

	if (keyCode == 8) {
		allowKey = true;
	}

	if (allowKey == true) {
		return stupidMac == true ? keyCode : true;
	} else {
		return stupidMac == true ? 0 : false;
	}
}

function truncatefield(obj) {
	var charsLeft = 200 - messageLength( obj.form )
	if (charsLeft < 0) {
		obj.value = obj.value.substring(0, obj.value.length + charsLeft)
		charsLeft = 0
	}
	obj.form.charsleft.value = charsLeft;
}

//-->
</script>
